@@ -1,4 +1,4 @@
-#include <QtTest/QtTest>
+#include <QtTest/QTest>
 
 #include <poppler-qt6.h>
 
@@ -8,7 +8,7 @@ class TestActualText : public QObject
 {
     Q_OBJECT
 public:
-    TestActualText(QObject *parent = nullptr) : QObject(parent) { }
+    explicit TestActualText(QObject *parent = nullptr) : QObject(parent) { }
 private slots:
     void checkActualText1();
     void checkActualText2();
